package com.muyu.cloud.pay.controller;

import com.muyu.cloud.pay.domain.OrderPayCustomer;
import com.muyu.cloud.pay.domain.req.CustomerListReq;
import com.muyu.cloud.pay.domain.resp.CustomerResp;
import com.muyu.cloud.pay.service.OrderPayCustomerService;
import com.muyu.common.core.domain.Result;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;

import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

/**
 * @Author：yang
 * @Package：com.muyu.cloud.pay.controller
 * @Project：cloud-pay
 * @name：OrderPayCustomerController
 * @Date：2024/8/5 20:05
 */
@Slf4j
@RestController
@RequestMapping("/customer")
@RequiredArgsConstructor
@Tag(name = "客户控制层",description = "进行客户管理，查看等相关操作")
public class OrderPayCustomerController {

    /**
     * 客户业务层
     */
//    @NotNull
    private final OrderPayCustomerService orderPayCustomerService;

    /**
     * 查询所有客户
     * @param customerListReq 客户列表请求参数
     * @return 客户列表
     */
    @RequestMapping(path = "/list" ,method = RequestMethod.POST)
    @Operation(summary = "查询客户",description = "根据客户的名称，编码，是否开启等可以进行客户的筛选")
    public Result<List<CustomerResp>> selectList(
            @Validated @RequestBody CustomerListReq customerListReq){
        return Result.success(
                orderPayCustomerService.selectList(customerListReq)
        );
    }

}
