package com.muyu.cloud.pay.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.muyu.cloud.pay.domain.OrderPayCustomer;
import com.muyu.cloud.pay.domain.OrderPayInfo;
import com.muyu.cloud.pay.domain.req.CustomerListReq;
import com.muyu.cloud.pay.domain.resp.CustomerOrderPaySimpleResp;
import com.muyu.cloud.pay.domain.resp.CustomerResp;
import com.muyu.cloud.pay.mapper.OrderPayCustomerMapper;
import com.muyu.cloud.pay.service.OrderPayCustomerService;
import com.muyu.cloud.pay.service.OrderPayService;
import com.muyu.common.core.enums.SysPayType;
import org.apache.catalina.mapper.Mapper;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.List;
import java.util.function.Function;

/**
 * @Author：yang
 * @Package：com.muyu.cloud.pay.service.impl.OrderPayCustomerService
 * @Project：cloud-pay
 * @name：impl
 * @Date：2024/8/5 19:56
 */
@Service
public class OrderPayCustomerServiceImpl
        extends ServiceImpl<OrderPayCustomerMapper,OrderPayCustomer>
        implements OrderPayCustomerService {

    @Resource(type = OrderPayServiceImpl.class)
    private OrderPayService orderPayService;

    @Override
    public List<CustomerResp> selectList(CustomerListReq customerListReq) {

        LambdaQueryWrapper<OrderPayCustomer> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.like(
                StringUtils.isNotEmpty(customerListReq.getAppName()),
                OrderPayCustomer::getAppName,customerListReq.getClass()
        );
        queryWrapper.like(
                StringUtils.isNotEmpty(customerListReq.getAppCode()),
                OrderPayCustomer::getAppCode,customerListReq.getClass()
        );
        queryWrapper.eq(
                StringUtils.isNotEmpty(customerListReq.getStatus()),
                OrderPayCustomer::getStatus,customerListReq.getClass()
        );
        List<OrderPayCustomer> orderPayCustomerList = this.list(queryWrapper);
        return orderPayCustomerList.stream()
                .map(orderPayCustomer -> CustomerResp.customerBuild(
                        orderPayCustomer,
                        () -> orderPayService.selectOrderPayByAppCodeAndLimit(orderPayCustomer.getAppCode(),5)
                                .stream()
                                .map(OrderPayInfo::buildCustomerOrderPaySimpleResp)
                                .toList()
                        )
                )
                .toList();
    }
}
